==> opentoonz-dmo_1.5.0.orig.tar.xz: opentoonz-1.5.0/toonz/sources/translations/korean/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
<context>
    <name>AviWriterProperties</name>
    <message>
        <source>Codec</source>
        <translation>코덱</translation>
    </message>
    <message>
        <source>Uncompressed</source>
        <translation>압축해제</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Looping</source>
        <translation>반복</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation>팔레트 생성</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <source>Alpha Channel</source>
        <translation>알파 채널</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg 시간초과.
파일에 오류가 있는지 확인하십시요.
파일이 재생되지 않거나 불완전 한 경우, 기본 설정에서 FFmpeg 시간초과를 설정하세요.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation>32비트</translation>
    </message>
    <message>
        <source>48 bits</source>
        <translation>48비트</translation>
    </message>
    <message>
        <source>64 bits</source>
        <translation>64비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation>8비트</translation>
    </message>
    <message>
        <source>Endianess</source>
        <translation>엔디안</translation>
    </message>
    <message>
        <source>Big Endian</source>
        <translation>빅 엔디안</translation>
    </message>
    <message>
        <source>Little Endian</source>
        <translation>리틀 엔디안</translation>
    </message>
    <message>
        <source>RLE-Compressed</source>
        <translation>RLE 압축</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <source>Top Padding</source>
        <translation>위쪽 여백</translation>
    </message>
    <message>
        <source>Bottom Padding</source>
        <translation>아래 여백</translation>
    </message>
    <message>
        <source>Left Padding</source>
        <translation>왼쪽 여백</translation>
    </message>
    <message>
        <source>Right Padding</source>
        <translation>오른쪽 여백</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>포맷</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>격자</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>수직선</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>수평</translation>
    </message>
    <message>
        <source>Individual</source>
        <translation>개별</translation>
    </message>
    <message>
        <source>Trim Empty Space</source>
        <translation>빈 공간 잘라내기</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <source>Stroke Mode</source>
        <translation>스트로크 모드</translation>
    </message>
    <message>
        <source>Outline Quality</source>
        <translation>윤곽 품질</translation>
    </message>
    <message>
        <source>Centerline</source>
        <translation>중심선</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>윤곽선</translation>
    </message>
    <message>
        <source>High</source>
        <translation>높은</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>낮은</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>16 bits</source>
        <translation>16비트</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation>32비트</translation>
    </message>
    <message>
        <source>Compression</source>
        <translation>압축</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <source>Byte Ordering</source>
        <translation>바이트 순서</translation>
    </message>
    <message>
        <source>Compression Type</source>
        <translation>압축</translation>
    </message>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24(RGB)</source>
        <translation></translation>
    </message>
    <message>
        <source>48(RGB)</source>
        <translation></translation>
    </message>
    <message>
        <source> 1(BW)</source>
        <translation>1(흑백)</translation>
    </message>
    <message>
        <source> 8(GREYTONES)</source>
        <translation>8(그레이 스케일)</translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation>방향</translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation>상단 왼쪽</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation>상단 오른쪽</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation>하단 오른쪽</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation>하단 왼쪽</translation>
    </message>
    <message>
        <source>Left Top</source>
        <translation>왼쪽상단</translation>
    </message>
    <message>
        <source>Left Bottom</source>
        <translation>왼쪽 하단</translation>
    </message>
    <message>
        <source>Right Top</source>
        <translation>오른쪽 상단</translation>
    </message>
    <message>
        <source>Right Bottom</source>
        <translation>오른쪽 하단</translation>
    </message>
    <message>
        <source>32(RGBA)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>64(RGBA)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.6.0.orig.tar.xz: opentoonz-1.6.0/toonz/sources/translations/korean/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
<context>
    <name>AviWriterProperties</name>
    <message>
        <source>Codec</source>
        <translation>코덱</translation>
    </message>
    <message>
        <source>Uncompressed</source>
        <translation>압축해제</translation>
    </message>
</context>
<context>
    <name>ExrWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>48(RGB Half Float)</source>
        <translation>48(RGB 하프 플로트)</translation>
    </message>
    <message>
        <source>64(RGBA Half Float)</source>
        <translation>64(RGB 하프 플로트)</translation>
    </message>
    <message>
        <source>Compression Type</source>
        <translation>압축</translation>
    </message>
    <message>
        <source>No compression</source>
        <translation>압축 없음</translation>
    </message>
    <message>
        <source>Run Length Encoding (RLE)</source>
        <translation>실행길이 인코팅(RLE)</translation>
    </message>
    <message>
        <source>ZIP compression per Scanline (ZIPS)</source>
        <translation>스캔 단위로 ZIP 압축(ZIPS)</translation>
    </message>
    <message>
        <source>ZIP compression per scanline band (ZIP)</source>
        <translation>스캔라인 밴드당 ZIP 압축(ZIP)</translation>
    </message>
    <message>
        <source>PIZ-based wavelet compression (PIZ)</source>
        <translation>PIZ-기반 웨이블릿 압축(PIZ)</translation>
    </message>
    <message>
        <source>Storage Type</source>
        <translation>저장 유형</translation>
    </message>
    <message>
        <source>Scan-line based</source>
        <translation>스캔-라인 기반</translation>
    </message>
    <message>
        <source>Tile based</source>
        <translation>티일기반</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Looping</source>
        <translation>반복</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation type="vanished">팔레트 생성</translation>
    </message>
    <message>
        <source>Global Palette</source>
        <translation>전체 팔레트</translation>
    </message>
    <message>
        <source>Global Palette + Sierra Dither</source>
        <translation>잔체 팔레트 + 시에라 디더</translation>
    </message>
    <message>
        <source>Global Palette + Bayer2 Dither</source>
        <translation>전체 팔레트 + 바이엘2 디더</translation>
    </message>
    <message>
        <source>Global Palette + Bayer1 Dither</source>
        <translation>전체 팔레트 + 바이엘1 디더</translation>
    </message>
    <message>
        <source>Diff Palette</source>
        <translation>디프 팔레트</translation>
    </message>
    <message>
        <source>Diff Palette + Sierra Dither</source>
        <translation>디프 팔레트 + 시에라 더디</translation>
    </message>
    <message>
        <source>Diff Palette + Bayer2 Dither</source>
        <translation>디프 팔레트 + 바이엘2 디더</translation>
    </message>
    <message>
        <source>Diff Palette + Bayer1 Dither</source>
        <translation>디프 팔레트 + 바이엘2 디더</translation>
    </message>
    <message>
        <source>New Pal Per Frame</source>
        <translation>프레임당 새친구</translation>
    </message>
    <message>
        <source>New Pal Per Frame + Sierra Dither</source>
        <translation>프레임당 새친구 + 시에라 디더</translation>
    </message>
    <message>
        <source>New Pal Per Frame + Bayer2 Dither</source>
        <translation>프레임당 새친구 + 바이엘2 디더</translation>
    </message>
    <message>
        <source>New Pal Per Frame + Bayer1 Dither</source>
        <translation>프레임당 새친구 + 바이엘1 디더</translation>
    </message>
    <message>
        <source>Opaque, Dither, 256 Colors Only</source>
        <translation>불투명, 디더, 266색만</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>모드</translation>
    </message>
    <message>
        <source>Max Colors</source>
        <translation>최대 색상</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <source>Alpha Channel</source>
        <translation>알파 채널</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg 시간초과.
파일에 오류가 있는지 확인하십시요.
파일이 재생되지 않거나 불완전 한 경우, 기본 설정에서 FFmpeg 시간초과를 설정하세요.</translation>
    </message>
    <message>
        <source>FFmpeg returned error-code: %1</source>
        <translation>FFmpeg 시간초과 오류 코드: %1</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation>32비트</translation>
    </message>
    <message>
        <source>48 bits</source>
        <translation>48비트</translation>
    </message>
    <message>
        <source>64 bits</source>
        <translation>64비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation>8비트</translation>
    </message>
    <message>
        <source>Endianess</source>
        <translation>엔디안</translation>
    </message>
    <message>
        <source>Big Endian</source>
        <translation>빅 엔디안</translation>
    </message>
    <message>
        <source>Little Endian</source>
        <translation>리틀 엔디안</translation>
    </message>
    <message>
        <source>RLE-Compressed</source>
        <translation>RLE 압축</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <source>Top Padding</source>
        <translation>위쪽 여백</translation>
    </message>
    <message>
        <source>Bottom Padding</source>
        <translation>아래 여백</translation>
    </message>
    <message>
        <source>Left Padding</source>
        <translation>왼쪽 여백</translation>
    </message>
    <message>
        <source>Right Padding</source>
        <translation>오른쪽 여백</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>포맷</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>격자</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>수직선</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>수평</translation>
    </message>
    <message>
        <source>Individual</source>
        <translation>개별</translation>
    </message>
    <message>
        <source>Trim Empty Space</source>
        <translation>빈 공간 잘라내기</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <source>Stroke Mode</source>
        <translation>스트로크 모드</translation>
    </message>
    <message>
        <source>Outline Quality</source>
        <translation>윤곽 품질</translation>
    </message>
    <message>
        <source>Centerline</source>
        <translation>중심선</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>윤곽선</translation>
    </message>
    <message>
        <source>High</source>
        <translation>높은</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>낮은</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>16 bits</source>
        <translation>16비트</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>32 bits</source>
        <translation>32비트</translation>
    </message>
    <message>
        <source>Compression</source>
        <translation>압축</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <source>Byte Ordering</source>
        <translation>바이트 순서</translation>
    </message>
    <message>
        <source>Compression Type</source>
        <translation>압축</translation>
    </message>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24(RGB)</source>
        <translation>24(RGBA)</translation>
    </message>
    <message>
        <source>48(RGB)</source>
        <translation>48(RGBA)</translation>
    </message>
    <message>
        <source> 1(BW)</source>
        <translation>1(흑과 백)</translation>
    </message>
    <message>
        <source> 8(GREYTONES)</source>
        <translation>8(회색)</translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation>방향</translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation>상단 왼쪽</translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation>상단 오른쪽</translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation>하단 오른쪽</translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation>하단 왼쪽</translation>
    </message>
    <message>
        <source>Left Top</source>
        <translation>왼쪽상단</translation>
    </message>
    <message>
        <source>Left Bottom</source>
        <translation>왼쪽 하단</translation>
    </message>
    <message>
        <source>Right Top</source>
        <translation>오른쪽 상단</translation>
    </message>
    <message>
        <source>Right Bottom</source>
        <translation>오른쪽 하단</translation>
    </message>
    <message>
        <source>32(RGBA)</source>
        <translation>32(RGBA)</translation>
    </message>
    <message>
        <source>64(RGBA)</source>
        <translation>64(RGBA)</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>비율</translation>
    </message>
</context>
</TS>
